# SPDX-FileCopyrightText: Copyright 2016, Siavash Ameli <sameli@berkeley.edu>
# SPDX-License-Identifier: BSD-3-Clause
# SPDX-FileType: SOURCE
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the license found in the LICENSE.txt file in the root
# directory of this source tree.


# =======
# Imports
# =======

import os

__all__ = ['License']


# ===========
# Get Version
# ===========

def _get_version():
    """
    Get the version of the package by reading __version__.py file.
    """

    version_dummy = {}
    current_dir = os.path.realpath(os.path.dirname(__file__))
    parent_dir = os.path.dirname(current_dir)
    version_file = os.path.join(parent_dir, '__version__.py')
    exec(open(version_file, 'r').read(), version_dummy)
    version = version_dummy['__version__']

    return version


# =======
# License
# =======

class License(object):
    """
    License information used in output nc files global attributes.
    """

    author_name = "Siavash Ameli"
    author_institution = "University of California, Berkeley"
    author_email = "sameli@berkeley.edu"

    output_file_title = "Restore Incomplete Oceanographic Data"
    output_file_history = \
        "This file is generated by RestoreIO: an application to restore " + \
        "incomplete oceanographic datasets, with specific focus on ocean " + \
        "surface velocity data (https://restoreio.org)."
    output_file_project = \
        "Advanced Lagrangian Predictions for Hazards Assessments (NSF-ALPHA)"
    output_file_acknowledgement = \
        "This material is based upon work supported by the National " + \
        "Science Foundation Graduate Research Fellowship under Grant " + \
        "No. 1520825."
    output_file_license = "CC0 1.0"

    package_name = "RestoreIO"
    package_url = "https://restoreio.org"
    package_version = _get_version()
    package_license = "3-Clause BSD"
